Module beamlit.models.invite_workspace_user_body
================================================

Classes
-------

`InviteWorkspaceUserBody(email: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Attributes:
        email (Union[Unset, str]):
    
    Method generated by attrs for class InviteWorkspaceUserBody.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `email: beamlit.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :